# Security Policy

## Supported Versions

| Version | Supported |
| ------- | --------- |
| 0.1.x   | Yes       |

## Reporting a Vulnerability

If you discover a security vulnerability in tethered, please report it
**privately** using
[GitHub's private vulnerability reporting](https://github.com/shcherbak-ai/tethered/security/advisories/new).

Please avoid opening public issues for security vulnerabilities.

Confirmed vulnerabilities will be addressed in a patch release.
